from __future__ import annotations


for i in range(1000):
    exec(f"def test_func_{i}(): pass")
